@@ -22,6 +22,7 @@ from rdflib import (
     Namespace,
     OWL,
     RDF,
+    RDFS,
     SKOS,
     URIRef,
     XSD,
@@ -32,7 +33,6 @@ import validators
 from modelldcatnotordf.document import FoafDocument
 from modelldcatnotordf.licensedocument import LicenseDocument
 
-
 DCAT = Namespace("http://www.w3.org/ns/dcat#")
 ODRL = Namespace("http://www.w3.org/ns/odrl/2/")
 PROV = Namespace("http://www.w3.org/ns/prov#")
@@ -44,10 +44,16 @@ ADMS = Namespace("http://www.w3.org/ns/adms#")
 class Standard:
     """A class representing a dct:Standard."""
 
-    __slots__ = ("_g", "_identifier")
-
     _g: Graph
     _identifier: URI
+    _title: dict
+    _has_reference: str
+    _has_version_number: str
+
+    def __init__(self, identifier: Optional[str] = None) -> None:
+        """Inits InformationModel object with default values."""
+        if identifier:
+            self.identifier = identifier
 
     @property
     def identifier(self) -> str:
@@ -58,6 +64,36 @@ class Standard:
     def identifier(self, identifier: str) -> None:
         self._identifier = URI(identifier)
 
+    @property
+    def title(self) -> dict:
+        """Get for title attribute."""
+        return self._title
+
+    @title.setter
+    def title(self, title: dict) -> None:
+        """Set for title attribute."""
+        self._title = title
+
+    @property
+    def has_reference(self: Standard) -> str:
+        """Get for has_reference."""
+        return self._has_reference
+
+    @has_reference.setter
+    def has_reference(self: Standard, has_reference: str) -> None:
+        """Set for has_reference."""
+        self._has_reference = URI(has_reference)
+
+    @property
+    def has_version_number(self: Standard) -> str:
+        """Get for has_version_number."""
+        return self._has_version_number
+
+    @has_version_number.setter
+    def has_version_number(self: Standard, has_version_number: str) -> None:
+        """Set for has_version_number."""
+        self._has_version_number = has_version_number
+
     def to_rdf(
         self, format: str = "turtle", encoding: Optional[str] = "utf-8"
     ) -> bytes:
@@ -88,10 +124,34 @@ class Standard:
 
         self._g.add((_self, RDF.type, DCTERMS.Standard))
 
+        if getattr(self, "title", None):
+            for key in self.title:
+                self._g.add(
+                    (
+                        URIRef(self.identifier),
+                        DCTERMS.title,
+                        Literal(self.title[key], lang=key),
+                    )
+                )
+
+        if getattr(self, "has_reference", None):
+            self._g.add(
+                (URIRef(self.identifier), RDFS.seeAlso, URIRef(self.has_reference))
+            )
+
+        if getattr(self, "has_version_number", None):
+            self._g.add(
+                (
+                    URIRef(self.identifier),
+                    OWL.versionInfo,
+                    Literal(self.has_version_number),
+                )
+            )
+
         return self._g
 
 
-class InformationModel(Resource):
+class InformationModel(Resource, Standard):
     """A class representing a modelldatno:InformationModel."""
 
     __slots__ = (
